<?php

namespace Epin\Litecms\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Epin\Litecms\Http\Requests\EpinRequest;
use Epin\Litecms\Interfaces\EpinRepositoryInterface;
use Epin\Litecms\Models\Epin;

/**
 * Resource controller class for epin.
 */
class EpinResourceController extends BaseController
{

    /**
     * Initialize epin resource controller.
     *
     * @param type EpinRepositoryInterface $epin
     *
     * @return null
     */
    public function __construct(EpinRepositoryInterface $epin)
    {
        parent::__construct();
        $this->repository = $epin;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Epin\Litecms\Repositories\Criteria\EpinResourceCriteria::class);
    }

    /**
     * Display a list of epin.
     *
     * @return Response
     */
    public function index(EpinRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Epin\Litecms\Repositories\Presenter\EpinPresenter::class)
                ->$function();
        }

        $epins = $this->repository->paginate();

        return $this->response->title(trans('litecms::epin.names'))
            ->view('litecms::epin.index', true)
            ->data(compact('epins'))
            ->output();
    }

    /**
     * Display epin.
     *
     * @param Request $request
     * @param Model   $epin
     *
     * @return Response
     */
    public function show(EpinRequest $request, Epin $epin)
    {

        if ($epin->exists) {
            $view = 'litecms::epin.show';
        } else {
            $view = 'litecms::epin.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('litecms::epin.name'))
            ->data(compact('epin'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new epin.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(EpinRequest $request)
    {

        $epin = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('litecms::epin.name')) 
            ->view('litecms::epin.create', true) 
            ->data(compact('epin'))
            ->output();
    }

    /**
     * Create new epin.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EpinRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $epin                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('litecms::epin.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('litecms/epin/' . $epin->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/litecms/epin'))
                ->redirect();
        }

    }

    /**
     * Show epin for editing.
     *
     * @param Request $request
     * @param Model   $epin
     *
     * @return Response
     */
    public function edit(EpinRequest $request, Epin $epin)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('litecms::epin.name'))
            ->view('litecms::epin.edit', true)
            ->data(compact('epin'))
            ->output();
    }

    /**
     * Update the epin.
     *
     * @param Request $request
     * @param Model   $epin
     *
     * @return Response
     */
    public function update(EpinRequest $request, Epin $epin)
    {
        try {
            $attributes = $request->all();

            $epin->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('litecms::epin.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('litecms/epin/' . $epin->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('litecms/epin/' . $epin->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the epin.
     *
     * @param Model   $epin
     *
     * @return Response
     */
    public function destroy(EpinRequest $request, Epin $epin)
    {
        try {

            $epin->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('litecms::epin.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('litecms/epin/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('litecms/epin/' . $epin->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple epin.
     *
     * @param Model   $epin
     *
     * @return Response
     */
    public function delete(EpinRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('litecms::epin.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('litecms/epin'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/litecms/epin'))
                ->redirect();
        }

    }

    /**
     * Restore deleted epins.
     *
     * @param Model   $epin
     *
     * @return Response
     */
    public function restore(EpinRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('litecms::epin.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/litecms/epin'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/litecms/epin/'))
                ->redirect();
        }

    }

}
